@@ -19,22 +19,25 @@ from mayan.apps.events.links import (
 from mayan.apps.events.permissions import permission_events_view
 from mayan.apps.navigation.classes import SourceColumn
 
-from .classes import ImportSetupBackend
+from .classes import ImportSetupBackend, ModelFiler
 from .events import (
     event_import_setup_edited, event_import_setup_processed,
     event_import_setup_item_completed
 )
 from .links import (
     link_import_setup_backend_selection, link_import_setup_delete,
-    link_import_setup_edit, link_import_setup_process,
+    link_import_setup_clear, link_import_setup_edit,
     link_import_setup_item_multiple_delete,
-    link_import_setup_item_multiple_process, link_import_setup_clear,
-    link_import_setup_items_list, link_import_setup_list,
-    link_import_setup_populate, link_import_setup_setup
+    link_import_setup_item_multiple_process, link_import_setup_items_list,
+    link_import_setup_multiple_clear, link_import_setup_multiple_populate,
+    link_import_setup_multiple_process, link_import_setup_populate,
+    link_import_setup_process, link_import_setup_list,
+    link_import_setup_setup, link_model_filer_load, link_model_filer_save
 )
 from .permissions import (
     permission_import_setup_delete, permission_import_setup_edit,
-    permission_import_setup_process, permission_import_setup_view
+    permission_import_setup_process, permission_import_setup_view,
+    permission_model_filer_load, permission_model_filer_save
 )
 
 logger = logging.getLogger(name=__name__)
@@ -70,12 +73,15 @@ class ImporterApp(MayanAppConfig):
             )
         )
 
+        ModelFiler(bulk_size=250, model=ImportSetupItem)
+
         ModelPermission.register(
             model=ImportSetup, permissions=(
                 permission_acl_edit, permission_acl_view,
                 permission_events_view, permission_import_setup_delete,
                 permission_import_setup_edit, permission_import_setup_process,
-                permission_import_setup_view
+                permission_import_setup_view, permission_model_filer_load,
+                permission_model_filer_save
             )
         )
 
@@ -115,6 +121,8 @@ class ImporterApp(MayanAppConfig):
             attribute='state_data', source=ImportSetupItem
         )
 
+        # ImportSetup
+
         menu_list_facet.bind_links(
             links=(
                 link_acl_list, link_events_for_object,
@@ -123,11 +131,20 @@ class ImporterApp(MayanAppConfig):
             ), sources=(ImportSetup,)
         )
 
+        menu_multi_item.bind_links(
+            links=(
+                link_import_setup_multiple_clear,
+                link_import_setup_multiple_populate,
+                link_import_setup_multiple_process,
+            ), sources=(ImportSetup,)
+        )
+
         menu_object.bind_links(
             links=(
                 link_import_setup_delete, link_import_setup_edit,
                 link_import_setup_process, link_import_setup_clear,
-                link_import_setup_populate
+                link_import_setup_populate,
+                link_model_filer_load, link_model_filer_save
             ), sources=(ImportSetup,)
         )
         menu_secondary.bind_links(
@@ -141,6 +158,8 @@ class ImporterApp(MayanAppConfig):
             links=(link_import_setup_setup,)
         )
 
+        # Import setup item
+
         menu_multi_item.bind_links(
             links=(
                 link_import_setup_item_multiple_delete,
