@@ -10,6 +10,9 @@ event_import_setup_created = namespace.add_event_type(
 event_import_setup_edited = namespace.add_event_type(
     label=_('Import setup edited'), name='import_setup_edited'
 )
-event_import_setup_executed = namespace.add_event_type(
-    label=_('Import setup executed'), name='import_setup_executed'
+event_import_setup_processed = namespace.add_event_type(
+    label=_('Import setup processed'), name='import_setup_processed'
+)
+event_import_setup_item_completed = namespace.add_event_type(
+    label=_('Import setup item completed'), name='import_setup_item_completed'
 )
