@@ -28,3 +28,12 @@ icon_import_setup_list = Icon(
 icon_import_setup_populate = Icon(
     driver_name='fontawesome', symbol='file-signature'
 )
+
+# Model filer
+
+icon_model_filer_load = Icon(
+    driver_name='fontawesome', symbol='upload'
+)
+icon_model_filer_save = Icon(
+    driver_name='fontawesome', symbol='download'
+)
