@@ -8,12 +8,14 @@ from .icons import (
     icon_import_setup_edit, icon_import_setup_process,
     icon_import_setup_item_delete, icon_import_setup_item_process,
     icon_import_setup_clear, icon_import_setup_items_list,
-    icon_import_setup_list, icon_import_setup_populate
+    icon_import_setup_list, icon_import_setup_populate,
+    icon_model_filer_load, icon_model_filer_save
 )
 from .permissions import (
     permission_import_setup_create, permission_import_setup_delete,
     permission_import_setup_edit, permission_import_setup_process,
-    permission_import_setup_view
+    permission_import_setup_view, permission_model_filer_load,
+    permission_model_filer_save
 )
 
 
@@ -41,18 +43,16 @@ link_import_setup_edit = Link(
     permissions=(permission_import_setup_edit,), text=_('Edit'),
     view='importer:import_setup_edit'
 )
-link_import_setup_process = Link(
-    args='resolved_object.pk', conditional_disable=conditional_disable_import_has_items,
-    icon_class=icon_import_setup_process,
-    permissions=(permission_import_setup_process,), text=_('Process'),
-    view='importer:import_setup_process'
-)
 link_import_setup_clear = Link(
     args='resolved_object.pk', conditional_disable=conditional_disable_import_has_items,
     icon_class=icon_import_setup_clear,
     permissions=(permission_import_setup_process,), text=_('Clear items'),
     view='importer:import_setup_clear'
 )
+link_import_setup_multiple_clear = Link(
+    icon_class=icon_import_setup_clear, text=_('Clear items'),
+    view='importer:import_setup_multiple_clear'
+)
 link_import_setup_items_list = Link(
     args='resolved_object.pk',
     icon_class=icon_import_setup_items_list,
@@ -70,6 +70,21 @@ link_import_setup_populate = Link(
     permissions=(permission_import_setup_process,), text=_('Populate'),
     view='importer:import_setup_populate'
 )
+link_import_setup_multiple_populate = Link(
+    icon_class=icon_import_setup_populate, text=_('Populate'),
+    view='importer:import_setup_multiple_populate'
+)
+link_import_setup_process = Link(
+    args='resolved_object.pk',
+    conditional_disable=conditional_disable_import_has_items,
+    icon_class=icon_import_setup_process,
+    permissions=(permission_import_setup_process,), text=_('Process'),
+    view='importer:import_setup_process'
+)
+link_import_setup_multiple_process = Link(
+    icon_class=icon_import_setup_process, text=_('Process'),
+    view='importer:import_setup_multiple_process'
+)
 link_import_setup_setup = Link(
     condition=get_cascade_condition(
         app_label='importer', model_name='ImportSetup',
@@ -93,3 +108,16 @@ link_import_setup_item_multiple_process = Link(
     permissions=(permission_import_setup_edit,),
     text=_('Process'), view='importer:import_setup_item_multiple_process'
 )
+
+# Model filer
+
+link_model_filer_load = Link(
+    args='resolved_object.pk', icon_class=icon_model_filer_load,
+    permissions=(permission_model_filer_load,),
+    text=_('Load'), view='importer:import_setup_load'
+)
+link_model_filer_save = Link(
+    args='resolved_object.pk', icon_class=icon_model_filer_save,
+    permissions=(permission_model_filer_save,),
+    text=_('Save'), view='importer:import_setup_save'
+)
