@@ -227,7 +227,7 @@ class ImportSetup(BackendModelMixin, models.Model):
                             'import_setup_item_id': item.pk
                         }
                     )
-                    if count > self.process_size:
+                    if count >= self.process_size:
                         break
         except Exception:
             self.state = SETUP_STATE_ERROR
@@ -316,6 +316,7 @@ class ImportSetupItem(models.Model):
                 self.state = ITEM_STATE_COMPLETE
                 self.state_data = ''
                 self.save()
+                shared_uploaded_file.delete()
 
         if document:
             item_setup_metadata_map = yaml_load(
