@@ -19,3 +19,12 @@ permission_import_setup_process = namespace.add_permission(
 permission_import_setup_view = namespace.add_permission(
     label=_('View import setups'), name='import_setup_view'
 )
+
+namespace = PermissionNamespace(label=_('Model filer'), name='model_filer')
+
+permission_model_filer_load = namespace.add_permission(
+    label=_('Save models to load'), name='model_filer_load'
+)
+permission_model_filer_save = namespace.add_permission(
+    label=_('Save models to file'), name='model_filer_save'
+)
