@@ -5,7 +5,8 @@ from .views import (
     ImportSetupDeleteView, ImportSetupEditView, ImportSetupProcessView,
     ImportSetupClearView, ImportSetupListView, ImportSetupPopulateView,
     ImportSetupItemDeleteView, ImportSetupItemListView,
-    ImportSetupItemProcessView
+    ImportSetupItemLoadView, ImportSetupItemProcessView,
+    ImportSetupItemSaveConfirmView, ImportSetupItemSaveDownloadView
 )
 
 urlpatterns_import_setup = [
@@ -39,14 +40,41 @@ urlpatterns_import_setup_items = [
         name='import_setup_clear',
         view=ImportSetupClearView.as_view()
     ),
+    url(
+        regex=r'^import_setups/multiple/clear/$',
+        name='import_setup_multiple_clear',
+        view=ImportSetupClearView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/(?P<import_setup_id>\d+)/load/$',
+        name='import_setup_load', view=ImportSetupItemLoadView.as_view()
+    ),
     url(
         regex=r'^import_setups/(?P<import_setup_id>\d+)/populate/$',
         name='import_setup_populate', view=ImportSetupPopulateView.as_view()
     ),
+    url(
+        regex=r'^import_setups/multiple/populate/$',
+        name='import_setup_multiple_populate',
+        view=ImportSetupPopulateView.as_view()
+    ),
     url(
         regex=r'^import_setups/(?P<import_setup_id>\d+)/process/$',
         name='import_setup_process', view=ImportSetupProcessView.as_view()
     ),
+    url(
+        regex=r'^import_setups/multiple/process/$',
+        name='import_setup_multiple_process',
+        view=ImportSetupProcessView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/(?P<import_setup_id>\d+)/save/$',
+        name='import_setup_save', view=ImportSetupItemSaveConfirmView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/(?P<shared_upload_file_id>\d+)/save/download/$',
+        name='import_setup_save_download', view=ImportSetupItemSaveDownloadView.as_view()
+    ),
     url(
         regex=r'^import_setups/(?P<import_setup_id>\d+)/items/$',
         name='import_setup_items_list',
