@@ -1,23 +1,25 @@
 import logging
 
 from django.contrib import messages
+from django.core.files import File
 from django.http import Http404, HttpResponseRedirect
-from django.shortcuts import get_object_or_404
 from django.template import RequestContext
 from django.urls import reverse, reverse_lazy
 from django.utils.translation import ungettext, ugettext_lazy as _
 
-from mayan.apps.acls.models import AccessControlList
 from mayan.apps.common.generics import (
     ConfirmView, FormView, MultipleObjectConfirmActionView,
     SingleObjectDeleteView, SingleObjectDynamicFormCreateView,
-    SingleObjectDynamicFormEditView, SingleObjectListView
+    SingleObjectDynamicFormEditView, SingleObjectDownloadView,
+    SingleObjectListView
 )
 from mayan.apps.common.mixins import ExternalObjectMixin
+from mayan.apps.common.models import SharedUploadedFile
 
-from .classes import ImportSetupBackend
+from .classes import ImportSetupBackend, ModelFiler
 from .forms import (
-    ImportSetupBackendSelectionForm, ImportSetupBackendDynamicForm
+    ImportSetupBackendSelectionForm, ImportSetupBackendDynamicForm,
+    ModelFilerUpload
 )
 from .icons import icon_import_setup_items_list, icon_import_setup_list
 from .links import (
@@ -27,11 +29,12 @@ from .models import ImportSetup, ImportSetupItem
 from .permissions import (
     permission_import_setup_create, permission_import_setup_delete,
     permission_import_setup_edit, permission_import_setup_process,
-    permission_import_setup_view
+    permission_import_setup_view, permission_model_filer_load,
+    permission_model_filer_save
 )
 from .tasks import (
-    task_import_setup_process, task_import_setup_item_process,
-    task_import_setup_populate
+    task_import_setup_item_process, task_import_setup_process,
+    task_import_setup_populate, task_model_filer_load, task_model_filer_save
 )
 
 logger = logging.getLogger(name=__name__)
@@ -139,35 +142,44 @@ class ImportSetupEditView(SingleObjectDynamicFormEditView):
         }
 
 
-class ImportSetupClearView(ConfirmView):
+class ImportSetupClearView(MultipleObjectConfirmActionView):
+    model = ImportSetup
+    object_permission = permission_import_setup_process
+    pk_url_kwarg = 'import_setup_id'
     post_action_redirect = reverse_lazy(
         viewname='importer:import_setup_list'
     )
+    success_message = _('%(count)d import setup cleared.')
+    success_message_plural = _('%(count)d import setups cleared.')
 
     def get_extra_context(self):
-        return {
-            'object': self.get_object(),
-            'title': _('Clear the items of import setup: %s') % self.get_object()
+        queryset = self.object_list
+
+        result = {
+            'title': ungettext(
+                singular='Clear the selected import setup?',
+                plural='Clear the selected import setups?',
+                number=queryset.count()
+            )
         }
 
-    def get_object(self):
-        return get_object_or_404(
-            klass=self.get_queryset(), pk=self.kwargs['import_setup_id']
-        )
+        if queryset.count() == 1:
+            result.update(
+                {
+                    'object': queryset.first(),
+                    'title': _('Clear import setup: %s') % queryset.first()
+                }
+            )
 
-    def get_queryset(self):
-        return AccessControlList.objects.restrict_queryset(
-            permission=permission_import_setup_process,
-            queryset=ImportSetup.objects.all(), user=self.request.user
-        )
+        return result
 
-    def view_action(self):
-        self.get_object().clear()
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
 
-        messages.success(
-            message=_('Import setup items cleared.'),
-            request=self.request
-        )
+    def object_action(self, instance, form=None):
+        instance.clear()
 
 
 class ImportSetupListView(SingleObjectListView):
@@ -192,95 +204,96 @@ class ImportSetupListView(SingleObjectListView):
         }
 
 
-class ImportSetupPopulateView(ConfirmView):
+class ImportSetupPopulateView(MultipleObjectConfirmActionView):
+    model = ImportSetup
+    object_permission = permission_import_setup_process
+    pk_url_kwarg = 'import_setup_id'
     post_action_redirect = reverse_lazy(
         viewname='importer:import_setup_list'
     )
+    success_message = _('%(count)d import setup populate queued.')
+    success_message_plural = _('%(count)d import setups populate queued.')
 
     def get_extra_context(self):
-        return {
-            'object': self.get_object(),
-            'title': _('Populate import setup: %s') % self.get_object()
+        queryset = self.object_list
+
+        result = {
+            'title': ungettext(
+                singular='Populate the selected import setup?',
+                plural='Populate the selected import setups?',
+                number=queryset.count()
+            )
         }
 
+        if queryset.count() == 1:
+            result.update(
+                {
+                    'object': queryset.first(),
+                    'title': _('Populate import setup: %s') % queryset.first()
+                }
+            )
+
+        return result
+
     def get_instance_extra_data(self):
         return {
-            '_event_actor': self.request.user
+            '_event_actor': self.request.user,
         }
 
-    def get_object(self):
-        return get_object_or_404(
-            klass=self.get_queryset(), pk=self.kwargs['import_setup_id']
-        )
-
-    def get_queryset(self):
-        return AccessControlList.objects.restrict_queryset(
-            permission=permission_import_setup_process,
-            queryset=ImportSetup.objects.all(), user=self.request.user
-        )
-
-    def view_action(self):
+    def object_action(self, instance, form=None):
         task_import_setup_populate.apply_async(
-            kwargs=dict(import_setup_id=self.get_object().pk)
-        )
-
-        messages.success(
-            message=_('Import setup populate queued.'), request=self.request
+            kwargs={'import_setup_id': instance.pk}
         )
 
 
-class ImportSetupProcessView(ConfirmView):
+class ImportSetupProcessView(MultipleObjectConfirmActionView):
+    model = ImportSetup
+    object_permission = permission_import_setup_process
+    pk_url_kwarg = 'import_setup_id'
     post_action_redirect = reverse_lazy(
         viewname='importer:import_setup_list'
     )
+    success_message = _('%(count)d import setup processing queued.')
+    success_message_plural = _('%(count)d import setups processing queued.')
 
-    def dispatch(self, request, *args, **kwargs):
-        result = super().dispatch(request=request, *args, **kwargs)
-        if self.get_object().items.count() == 0:
+    def get_extra_context(self):
+        queryset = self.object_list
+
+        result = {
+            'title': ungettext(
+                singular='Process the selected import setup?',
+                plural='Process the selected import setups?',
+                number=queryset.count()
+            )
+        }
+
+        if queryset.count() == 1:
+            result.update(
+                {
+                    'object': queryset.first(),
+                    'title': _('Process import setup: %s') % queryset.first()
+                }
+            )
+
+        return result
+
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
+
+    def object_action(self, instance, form=None):
+        if instance.items.count() == 0:
             messages.warning(
                 message=_(
-                    'Import setup does not have any item to process. Use the'
-                    'populate action first.'
-                ),
-                request=self.request
-            )
-            return HttpResponseRedirect(
-                redirect_to=reverse(viewname='importer:import_setup_list')
+                    'Import setup "%s" does not have any item to process. '
+                    'Use the populate action first.'
+                ) % instance, request=self.request
             )
         else:
-            return result
-
-    def get_extra_context(self):
-        return {
-            'object': self.get_object(),
-            'title': _('Process import setup: %s') % self.get_object()
-        }
-
-    def get_instance_extra_data(self):
-        return {
-            '_event_actor': self.request.user
-        }
-
-    def get_object(self):
-        return get_object_or_404(
-            klass=self.get_queryset(), pk=self.kwargs['import_setup_id']
-        )
-
-    def get_queryset(self):
-        return AccessControlList.objects.restrict_queryset(
-            permission=permission_import_setup_process,
-            queryset=ImportSetup.objects.all(), user=self.request.user
-        )
-
-    def view_action(self):
-        task_import_setup_process.apply_async(
-            kwargs=dict(import_setup_id=self.get_object().pk)
-        )
-
-        messages.success(
-            message=_('Import setup process queued.'),
-            request=self.request
-        )
+            task_import_setup_process.apply_async(
+                kwargs={'import_setup_id': instance.pk}
+            )
 
 
 class ImportSetupItemDeleteView(MultipleObjectConfirmActionView):
@@ -413,3 +426,96 @@ class ImportSetupItemProcessView(MultipleObjectConfirmActionView):
                 'import_setup_item_id': instance.pk
             }
         )
+
+
+class ImportSetupItemLoadView(ExternalObjectMixin, FormView):
+    external_object_class = ImportSetup
+    external_object_object_permission = permission_model_filer_load
+    external_object_pk_url_kwarg = 'import_setup_id'
+    form_class = ModelFilerUpload
+
+    def form_valid(self, form):
+        with self.request.FILES['uploaded_file'].open(mode='r') as file_object:
+            shared_upload_file = SharedUploadedFile.objects.create(
+                file=File(file_object),
+            )
+
+        full_model_name = ModelFiler.get_full_model_name(
+            model=self.external_object.items.model
+        )
+        task = task_model_filer_load.apply_async(
+            kwargs={
+                'field_defaults': {'import_setup_id': self.external_object.pk},
+                'full_model_name': full_model_name,
+                'shared_upload_file_id': shared_upload_file.pk
+            }
+        )
+        self.shared_upload_file_id = task.get()
+
+        messages.success(
+            message=_('File uploaded and queued for loading as models.'),
+            request=self.request
+        )
+        return HttpResponseRedirect(
+            redirect_to=reverse(viewname='importer:import_setup_list')
+        )
+
+    def get_extra_context(self):
+        return {
+            'object': self.get_external_object(),
+            'title': _(
+                'Load the items of import setup: %s'
+            ) % self.get_external_object()
+        }
+
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
+
+
+class ImportSetupItemSaveConfirmView(ExternalObjectMixin, ConfirmView):
+    external_object_class = ImportSetup
+    external_object_object_permission = permission_model_filer_save
+    external_object_pk_url_kwarg = 'import_setup_id'
+
+    def get_extra_context(self):
+        return {
+            'object': self.get_external_object(),
+            'title': _(
+                'Save the items of import setup: %s'
+            ) % self.get_external_object()
+        }
+
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
+
+    def get_success_url(self):
+        return reverse(
+            viewname='importer:import_setup_save_download', kwargs={
+                'shared_upload_file_id': self.shared_upload_file_id
+            }
+        )
+
+    def view_action(self):
+        full_model_name = ModelFiler.get_full_model_name(
+            model=self.external_object.items.model
+        )
+
+        task = task_model_filer_save.apply_async(
+            kwargs={
+                'filter_kwargs': {'import_setup': self.external_object.pk},
+                'full_model_name': full_model_name,
+            }
+        )
+        self.shared_upload_file_id = task.get()
+
+
+class ImportSetupItemSaveDownloadView(SingleObjectDownloadView):
+    model = SharedUploadedFile
+    pk_url_kwarg = 'shared_upload_file_id'
+
+    def get_download_filename(self):
+        return '{}.csv'.format(self.object)
